Sisyphus repositório
Última atualização: 1 outubro 2023 | SRPMs: 18631 | Visitas: 37037695
en ru br
ALT Linux repositórios
S:4.04-alt1
5.0: 3.02-alt4
4.1: 3.02-alt4.M41.1
4.0: 3.02-alt3
3.0: 3.00-alt5pl3
+backports:3.01-alt0.M30.2

Group :: Escritórios
RPM: xpdf

 Main   Changelog   Spec   Patches   Sources   Download   Gear   Bugs e FR  Repocop 

Patch: xpdf-3.01-resize.patch
Download


--- xpdf-3.01/xpdf/XPDFCore.cc.resize	2005-10-06 23:40:10.000000000 +0200
+++ xpdf-3.01/xpdf/XPDFCore.cc	2005-10-06 23:40:10.000000000 +0200
@@ -979,6 +979,9 @@
   XPDFCore *core = (XPDFCore *)ptr;
   XEvent event;
   Widget top;
+  Window rootWin;
+  int x1, y1;
+  Guint w1, h1, bw1, depth1;
   Arg args[2];
   int n;
   Dimension w, h;
@@ -986,15 +989,20 @@
 
   // find the top-most widget which has an associated window, and look
   // for a pending ConfigureNotify in the event queue -- if there is
   // one, that means we're still resizing, and we want to skip the
   // current event
   for (top = core->parentWidget;
        XtParent(top) && XtWindow(XtParent(top));
        top = XtParent(top)) ;
   if (XCheckTypedWindowEvent(core->display, XtWindow(top),
 			     ConfigureNotify, &event)) {
     XPutBackEvent(core->display, &event);
-    return;
+    XGetGeometry(core->display, event.xconfigure.window,
+		 &rootWin, &x1, &y1, &w1, &h1, &bw1, &depth1);
+    if ((Guint)event.xconfigure.width != w1 ||
+	(Guint)event.xconfigure.height != h1) {
+      return;
+    }
   }
 
   n = 0;
@@ -986,15 +989,20 @@
   // find the top-most widget which has an associated window, and look
   // for a pending ConfigureNotify in the event queue -- if there is
-  // one, that means we're still resizing, and we want to skip the
-  // current event
+  // one, and it specifies a different width or height, that means
+  // we're still resizing, and we want to skip the current event
   for (top = core->parentWidget;
        XtParent(top) && XtWindow(XtParent(top));
 
projeto & código: Vladimir Lettiev aka crux © 2004-2005, Andrew Avramenko aka liks © 2007-2008
mantenedor atual: Michael Shigorin
mantenedor da tradução: Fernando Martini aka fmartini © 2009